[−][src]Struct crypto::sha2::Sha224
The SHA-256 hash algorithm with the SHA-224 initial hash value. The result is truncated to 224 bits.
Methods
impl Sha224[src]
impl Sha224Trait Implementations
impl Digest for Sha224[src]
impl Digest for Sha224fn input(&mut self, d: &[u8])[src]
fn input(&mut self, d: &[u8])Provide message data. Read more
fn result(&mut self, out: &mut [u8])[src]
fn result(&mut self, out: &mut [u8])Retrieve the digest result. This method may be called multiple times. Read more
fn reset(&mut self)[src]
fn reset(&mut self)Reset the digest. This method must be called after result() and before supplying more data. Read more
fn output_bits(&self) -> usize[src]
fn output_bits(&self) -> usizeGet the output size in bits.
fn block_size(&self) -> usize[src]
fn block_size(&self) -> usizeGet the block size in bytes.
fn output_bytes(&self) -> usize[src]
fn output_bytes(&self) -> usizeGet the output size in bytes.
fn input_str(&mut self, input: &str)[src]
fn input_str(&mut self, input: &str)Convenience function that feeds a string into a digest. Read more
fn result_str(&mut self) -> String[src]
fn result_str(&mut self) -> StringConvenience function that retrieves the result of a digest as a String in hexadecimal format. Read more
impl Clone for Sha224[src]
impl Clone for Sha224fn clone(&self) -> Sha224[src]
fn clone(&self) -> Sha224Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Copy for Sha224[src]
impl Copy for Sha224Auto Trait Implementations